@@ -7,26 +7,19 @@ from navec.pq import PQ
 from ..log import log_info
 
 
-def pack(args):
-    pack_(
-        args.vocab, args.pq,
-        args.id
-    )
-
-
 def open_bin(path):
     return open(path, 'rb')
 
 
-def pack_(vocab, pq, id):
-    meta = Meta(id)
+def pack(args):
+    meta = Meta(args.id)
 
-    with open_bin(vocab) as file:
+    with open_bin(args.vocab) as file:
         vocab = Vocab.from_file(file)
 
-    with open_bin(pq) as file:
+    with open_bin(args.pq) as file:
         pq = PQ.from_file(file)
 
-    path = 'navec_%s.tar' % id
+    path = 'navec_%s.tar' % args.id
     log_info('Dumping %s', path)
     Navec(meta, vocab, pq).dump(path)
